@@ -7,15 +7,14 @@ from sql import Literal
 from sql.aggregate import Max, Sum
 from sql.functions import Extract, CharLength
 
+from trytond.i18n import gettext
 from trytond.model import ModelView, ModelSQL, fields, Unique
 from trytond.wizard import Wizard, StateView, StateAction, Button
 from trytond.pyson import Eval, PYSONEncoder, Date
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 
-__all__ = ['Line', 'EnterLinesStart', 'EnterLines',
-    'HoursEmployee', 'HoursEmployeeContext',
-    'HoursEmployeeWeekly', 'HoursEmployeeMonthly']
+from .exceptions import DurationValidationError
 
 
 class Line(ModelSQL, ModelView):
@@ -61,20 +60,21 @@ class Line(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Line, cls).__setup__()
+        cls._order = [
+            ('date', 'DESC'),
+            ('id', 'DESC'),
+            ]
         t = cls.__table__()
         cls._sql_constraints = [
             ('uuid_unique', Unique(t, t.uuid),
-                "The UUID of timesheet line must be unique."),
+                'timesheet.msg_line_uuid_unique'),
             ]
-        cls._order.insert(0, ('date', 'DESC'))
-        cls._error_messages.update({
-                'duration_positive': (
-                    'Duration of line "%(line)s" must be positive.'),
-                })
 
     @classmethod
     def __register__(cls, module_name):
-        cursor = Transaction().connection.cursor()
+        transaction = Transaction()
+        cursor = transaction.connection.cursor()
+        update = transaction.connection.cursor()
         table = cls.__table_handler__(module_name)
         sql_table = cls.__table__()
         pool = Pool()
@@ -88,7 +88,7 @@ class Line(ModelSQL, ModelView):
         # Migration from 3.4: new company field
         if created_company:
             # Don't use FROM because SQLite nor MySQL support it.
-            cursor.execute(*sql_table.update(
+            update.execute(*sql_table.update(
                     [sql_table.company], [work.select(work.company,
                             where=work.id == sql_table.work)]))
         # Migration from 3.4: change hours into timedelta duration
@@ -96,9 +96,9 @@ class Line(ModelSQL, ModelView):
             table.drop_constraint('check_move_hours_pos')
             cursor.execute(*sql_table.select(
                     sql_table.id, sql_table.hours))
-            for id_, hours in cursor.fetchall():
+            for id_, hours in cursor:
                 duration = datetime.timedelta(hours=hours)
-                cursor.execute(*sql_table.update(
+                update.execute(*sql_table.update(
                         [sql_table.duration],
                         [duration],
                         where=sql_table.id == id_))
@@ -134,9 +134,9 @@ class Line(ModelSQL, ModelView):
 
     def check_duration(self):
         if self.duration < datetime.timedelta():
-            self.raise_user_error('duration_positive', {
-                    'line': self.rec_name,
-                    })
+            raise DurationValidationError(
+                gettext('timesheet.msg_line_duration_positive',
+                    line=self.rec_name))
 
     @classmethod
     def copy(cls, lines, default=None):
@@ -204,6 +204,8 @@ class EnterLines(Wizard):
     enter = StateAction('timesheet.act_line_form')
 
     def do_enter(self, action):
+        pool = Pool()
+        Lang = pool.get('ir.lang')
         date = self.start.date
         date = Date(date.year, date.month, date.day)
         action['pyson_domain'] = PYSONEncoder().encode([
@@ -216,7 +218,10 @@ class EnterLines(Wizard):
                 'company': self.start.employee.company.id,
                 'date': date,
                 })
-        action['name'] += " - " + self.start.employee.rec_name
+        action['name'] += ' @ %(date)s - %(employee)s' % {
+            'date': Lang.get().strftime(self.start.date),
+            'employee': self.start.employee.rec_name,
+            }
         return action, {}
 
     def transition_enter(self):
@@ -316,9 +321,7 @@ class HoursEmployeeMonthly(ModelSQL, ModelView):
     'Hours per Employee per Month'
     __name__ = 'timesheet.hours_employee_monthly'
     year = fields.Char('Year')
-    month_internal = fields.Char('Month')
-    month = fields.Function(fields.Char('Month'),
-        'get_month', searcher='search_month')
+    month = fields.Many2One('ir.calendar.month', "Month")
     employee = fields.Many2One('company.employee', 'Employee')
     duration = fields.TimeDelta('Duration', 'company_work_time')
 
@@ -326,20 +329,20 @@ class HoursEmployeeMonthly(ModelSQL, ModelView):
     def __setup__(cls):
         super(HoursEmployeeMonthly, cls).__setup__()
         cls._order.insert(0, ('year', 'DESC'))
-        cls._order.insert(1, ('month', 'DESC'))
+        cls._order.insert(1, ('month.index', 'DESC'))
         cls._order.insert(2, ('employee', 'ASC'))
 
     @classmethod
     def table_query(cls):
         pool = Pool()
         Line = pool.get('timesheet.line')
+        Month = pool.get('ir.calendar.month')
         line = Line.__table__()
+        month = Month.__table__()
         type_name = cls.year.sql_type().base
         year_column = Extract('YEAR', line.date).cast(type_name).as_('year')
-        type_name = cls.month_internal.sql_type().base
-        month_column = Extract('MONTH', line.date).cast(type_name).as_(
-            'month_internal')
-        return line.select(
+        month_index = Extract('MONTH', line.date)
+        return line.join(month, condition=month_index == month.id).select(
             Max(Extract('MONTH', line.date)
                 + Extract('YEAR', line.date) * 100
                 + line.employee * 1000000).as_('id'),
@@ -348,19 +351,7 @@ class HoursEmployeeMonthly(ModelSQL, ModelView):
             Max(line.write_uid).as_('write_uid'),
             Max(line.write_date).as_('write_date'),
             year_column,
-            month_column,
+            month.id.as_('month'),
             line.employee,
             Sum(line.duration).as_('duration'),
-            group_by=(year_column, month_column, line.employee))
-
-    def get_month(self, name):
-        return '%02i' % int(self.month_internal)
-
-    @classmethod
-    def search_month(cls, name, domain):
-        return [('month_internal',) + tuple(domain[1:])]
-
-    @classmethod
-    def order_month(cls, tables):
-        table, _ = tables[None]
-        return [CharLength(table.month_internal), table.month_internal]
+            group_by=(year_column, month.id, line.employee))
