@@ -6,16 +6,17 @@ import datetime
 from sql import Literal
 from sql.aggregate import Sum
 
-from trytond.model import ModelView, ModelSQL, DeactivableMixin, fields, Unique
-from trytond.pyson import Not, Bool, Eval, If
+from trytond.i18n import gettext
+from trytond.model import ModelView, ModelSQL, ModelStorage, fields, Unique
+from trytond.pyson import Bool, Eval, If
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.tools import reduce_ids, grouped_slice
 
-__all__ = ['Work', 'WorkContext']
+from .exceptions import CompanyValidationError
 
 
-class Work(DeactivableMixin, ModelSQL, ModelView):
+class Work(ModelSQL, ModelView):
     'Work'
     __name__ = 'timesheet.work'
     name = fields.Char('Name',
@@ -55,10 +56,6 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
         select=True, help="Make the work belong to the company.")
     timesheet_lines = fields.One2Many('timesheet.line', 'work',
         'Timesheet Lines',
-        depends=['active'],
-        states={
-            'readonly': Not(Bool(Eval('active'))),
-            },
         help="Spend time on this work.")
     # Self referring field to use for aggregation in graph view
     work = fields.Function(fields.Many2One('timesheet.work', 'Work'),
@@ -70,12 +67,8 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
         t = cls.__table__()
         cls._sql_constraints += [
             ('origin_unique', Unique(t, t.origin, t.company),
-                'The origin must be unique per company.'),
+                'timesheet.msg_work_origin_unique_company'),
             ]
-        cls._error_messages.update({
-                'mismatch_company': ('The company of the work "%(work)s" '
-                    'is different than the origin\'s company'),
-                })
 
     @classmethod
     def __register__(cls, module_name):
@@ -113,7 +106,7 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
         # Migration from 4.0: remove timesheet_available
         if table_h.column_exist('timesheet_available'):
             cursor.execute(*table.delete(
-                    where=table.timesheet_available == False))
+                    where=table.timesheet_available == Literal(False)))
             table_h.drop_column('timesheet_available')
 
     @staticmethod
@@ -128,11 +121,9 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
     @classmethod
     def get_origin(cls):
         Model = Pool().get('ir.model')
+        get_name = Model.get_name
         models = cls._get_origin()
-        models = Model.search([
-                ('model', 'in', models),
-                ])
-        return [('', '')] + [(m.model, m.name) for m in models]
+        return [('', '')] + [(m, get_name(m)) for m in models]
 
     @classmethod
     def get_duration(cls, works, name):
@@ -162,7 +153,7 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
             cursor.execute(*query_table.select(table_w.id, Sum(line.duration),
                     where=red_sql & where,
                     group_by=table_w.id))
-            for work_id, duration in cursor.fetchall():
+            for work_id, duration in cursor:
                 # SQLite uses float for SUM
                 if duration and not isinstance(duration, datetime.timedelta):
                     duration = datetime.timedelta(seconds=duration)
@@ -173,7 +164,7 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
         return self.id
 
     def get_rec_name(self, name):
-        if self.origin:
+        if isinstance(self.origin, ModelStorage):
             return self.origin.rec_name
         else:
             return self.name
@@ -204,9 +195,9 @@ class Work(DeactivableMixin, ModelSQL, ModelView):
         super(Work, cls).validate(works)
         for work in works:
             if work.origin and not work._validate_company():
-                cls.raise_user_error('mismatch_company', {
-                        'work': work.rec_name,
-                        })
+                raise CompanyValidationError(
+                    gettext('timesheet.msg_work_company_different_origin',
+                        work=work.rec_name))
 
     def _validate_company(self):
         return True
